@@ -1,4 +1,4 @@
-# $Id: ja.rb,v 1.2 2003/03/23 03:37:13 hitoshi Exp $
+# $Id: ja.rb,v 1.3 2004/02/15 02:48:35 hitoshi Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 # You can redistribute it and/or modify it under the terms of
 # the Ruby's licence.
@@ -9,10 +9,11 @@ module Hiki
     def msg_diff; 'ʬ' end
     def msg_edit; 'Խ' end
     def msg_search; '' end
+    def msg_admin; '' end
     def msg_search_result; '' end
     def msg_search_hits; '\'%s\'ޤڡ%dڡ桢%dڡĤޤ' end
     def msg_search_not_found; '\'%s\'ޤڡϸĤޤǤ' end
-    def msg_search_comment; 'ƤΥڡñ򸡺ޤʸȾʸ϶̤ޤ' end
+    def msg_search_comment; 'ƤΥڡñ򸡺ޤʸȾʸ϶̤ޤȾѥڡñڤȻꤷñƴޤڡ򸡺ޤ' end
     def msg_frontpage; 'ȥå' end
     def msg_hitory; '' end
     def msg_index; 'ڡ' end
@@ -43,5 +44,8 @@ module Hiki
     def msg_delete; 'ڡޤ' end
     def msg_delete_page; 'ʲΥڡޤ' end
     def msg_follow_link; 'ʲΥ󥯤򤿤ɤäƤ: ' end
+    def msg_match_title; '[ȥ˰]' end
+    def msg_match_keyword; '[ɤ˰]' end
+    def msg_duplicate_page_title; 'ꤷȥϴ¸ߤƤޤ' end
   end
 end
